# Pylians3

Pylians stands for **Py**thon **li**braries for the **a**nalysis of **n**umerical **s**imulations. 

## Installation

For the stable version do:

``` sh
python -m pip install Pylians
```

For the development version do

```sh 
git clone https://github.com/franciscovillaescusa/Pylians3.git
cd Pylians3
python -m pip install .
```


## Usage

Pylians3 is a set of python libraries, written in python, cython and C, whose purposes is to facilitate the analysis of numerical simulations (both N-body and hydrodynamic). Among other things, they can be used to:

-   Compute density fields
-   Compute power spectra
-   Compute bispectra
-   Compute correlation functions
-   Identify voids
-   Populate halos with galaxies using an HOD
-   Apply HI+H2 corrections to the output of hydrodynamic simulations
-   Make 21cm maps
-   Compute DLAs column density distribution functions
-   Plot density fields and make movies

## Documentation 

See [here](https://pylians3.readthedocs.io/en/master/) for the detailed documentation. 
